Contains tons of structs used by the library
All examples here are based off the Torznab spec’s /api?caps example.
Structs
- Caps
- Holds the configuration for the capabilities of the Torznab server (used in
/api?t=caps) - Category
- Contains a category, for use in
Capsand searches as a query parameter - Config
- A struct that holds configuration for torznab-toolkit
The search function (
/api?t=search) and capabilities (/api?t=caps- structCaps) are required Everything else is optional - Genre
- Contains a genre, for use in
Capsand searches as a query parameter - Limits
- The maximum and defaults for the
limitparameter in queriesmaxis the maximum number of results the program can returndefaultis the default number of results the program will return - Search
Info - A struct holding the info for a type of search
- Search
Parameters - Holds the parameters for a search query
- Subcategory
- Contains subcategories, for use in
Category - Tag
- Contains a tag, for use in
Capsand searches as a query parameter - Torrent
- Holds the info for a torrent