pub struct Caps {
pub server_info: Option<HashMap<String, String>>,
pub limits: Limits,
pub searching: Vec<SearchInfo>,
pub categories: Vec<Category>,
pub genres: Option<Vec<Genre>>,
pub tags: Option<Vec<Tag>>,
}Expand description
Holds the configuration for the capabilities of the Torznab server (used in /api?t=caps)
It’s recommended to add any capabilities you want, and set available to false in the Caps struct for any currently unsupported search types.
Example, using other examples:
let mut info: HashMap<String, String> = HashMap::new();
info.insert("version".to_string(), "1.1".to_string());
let caps_data = Caps {
server_info: Some(info),
limits: query_limits,
searching: vec![tv_query_search_info],
categories: vec![category],
genres: Some(vec![genre]),
tags: Some(vec![tag]),
};Fields
server_info: Option<HashMap<String, String>>The server info, like title - optional
Examples: version, title, email, url, image
limits: LimitsThe max and default number of items to be returned by queries
searching: Vec<SearchInfo>Info about each type of search
categories: Vec<Category>What categories the server has
genres: Option<Vec<Genre>>What genres the server has (optional)
What torrents can be tagged with (optional)